=======
pydiggs
=======


.. image:: https://img.shields.io/pypi/v/pydiggs.svg
        :target: https://pypi.python.org/pypi/pydiggs

.. image:: https://travis-ci.com/xinp-hub/pydiggs.svg?branch=master
        :target: https://travis-ci.com/github/xinp-hub/pydiggs
        :alt: Build Status

.. image:: https://readthedocs.org/projects/pydiggs/badge/?version=latest
        :target: https://pydiggs.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/xinp-hub/pydiggs/shield.svg
     :target: https://pyup.io/account/repos/github/xinp-hub/pydiggs/
     :alt: Updates



A Python package for Data Interchange for Geotechnical and Geoenvironmental Specialists (DIGGS).


* Free software: GNU General Public License v3
* Documentation: https://pydiggs.readthedocs.io.
* GitHub: https://github.com/xinp-hub/pydiggs.


Features
--------

* Validate DIGGS instance files against DIGGS XSD and Schematron schemas.
